@@ -37,17 +37,17 @@ using namespace KHC;
 PluginTraverser::PluginTraverser( Navigator *navigator, QTreeWidget *parent )
   : DocEntryTraverser(),
   mListView( parent ),
-  mParentItem( 0 ),
-  mCurrentItem( 0 ),
+  mParentItem( nullptr ),
+  mCurrentItem( nullptr ),
   mNavigator( navigator )
 {
 }
 
 PluginTraverser::PluginTraverser( Navigator *navigator, NavigatorItem *parent )
   : DocEntryTraverser(),
-  mListView( 0 ),
+  mListView( nullptr ),
   mParentItem( parent ),
-  mCurrentItem( 0 ),
+  mCurrentItem( nullptr ),
   mNavigator( navigator )
 {
 }
@@ -55,7 +55,7 @@ PluginTraverser::PluginTraverser( Navigator *navigator, NavigatorItem *parent )
 void PluginTraverser::process( DocEntry *entry )
 {
   if ( !mListView && !mParentItem ) {
-    khcWarning() << "ERROR! Neither mListView nor mParentItem is set.";
+    qCWarning(KHC_LOG) << "ERROR! Neither mListView nor mParentItem is set.";
     return;
   }
 
@@ -69,7 +69,7 @@ void PluginTraverser::process( DocEntry *entry )
       mCurrentItem = new NavigatorAppItem( entry, mParentItem, mCurrentItem );
   } else if ( entry->khelpcenterSpecial() == QLatin1String("apps") ) {
     NavigatorAppGroupItem *appItem;
-    entry->setIcon( "kde" );
+    entry->setIcon( QStringLiteral("kde") );
     if ( mListView )
       appItem = new NavigatorAppGroupItem( entry, mListView, mCurrentItem );
     else
@@ -85,17 +85,17 @@ void PluginTraverser::process( DocEntry *entry )
     if ( entry->khelpcenterSpecial() == QLatin1String("konqueror") ) {
       mNavigator->insertParentAppDocs( entry->khelpcenterSpecial(), mCurrentItem );
     } else if ( entry->khelpcenterSpecial() == QLatin1String("kcontrol") ) {
-      mNavigator->insertKCMDocs( entry->khelpcenterSpecial(), mCurrentItem, QString("kcontrol") );
+      mNavigator->insertKCMDocs( entry->khelpcenterSpecial(), mCurrentItem, QStringLiteral("kcontrol") );
     } else if ( entry->khelpcenterSpecial() == QLatin1String("konquerorcontrol") ) {
-      mNavigator->insertKCMDocs( entry->khelpcenterSpecial(), mCurrentItem, QString("konquerorcontrol") );
+      mNavigator->insertKCMDocs( entry->khelpcenterSpecial(), mCurrentItem, QStringLiteral("konquerorcontrol") );
     } else if ( entry->khelpcenterSpecial() == QLatin1String("filemanagercontrol") ) {
-      mNavigator->insertKCMDocs( entry->khelpcenterSpecial(), mCurrentItem, QString("filemanagercontrol") );
+      mNavigator->insertKCMDocs( entry->khelpcenterSpecial(), mCurrentItem, QStringLiteral("filemanagercontrol") );
     } else if ( entry->khelpcenterSpecial() == QLatin1String("browsercontrol") ) {
-      mNavigator->insertKCMDocs( entry->khelpcenterSpecial(), mCurrentItem, QString("browsercontrol") );
+      mNavigator->insertKCMDocs( entry->khelpcenterSpecial(), mCurrentItem, QStringLiteral("browsercontrol") );
     } else if ( entry->khelpcenterSpecial() == QLatin1String("othercontrol") ) {
-      mNavigator->insertKCMDocs( entry->khelpcenterSpecial(), mCurrentItem, QString("othercontrol") );
+      mNavigator->insertKCMDocs( entry->khelpcenterSpecial(), mCurrentItem, QStringLiteral("othercontrol") );
     } else if ( entry->khelpcenterSpecial() == QLatin1String("kinfocenter") ) {
-      mNavigator->insertKCMDocs( entry->khelpcenterSpecial(), mCurrentItem, QString("kinfocenter") );
+      mNavigator->insertKCMDocs( entry->khelpcenterSpecial(), mCurrentItem, QStringLiteral("kinfocenter") );
     } else if ( entry->khelpcenterSpecial() == QLatin1String("kioslave") ) {
       mNavigator->insertIOSlaveDocs( entry->khelpcenterSpecial(), mCurrentItem );
     } else if ( entry->khelpcenterSpecial() == QLatin1String("info") ) {
@@ -115,8 +115,8 @@ DocEntryTraverser *PluginTraverser::createChild( DocEntry * /*entry*/ )
   if ( mCurrentItem ) {
     return new PluginTraverser( mNavigator, mCurrentItem );
   }
-  khcWarning() << "ERROR! mCurrentItem is not set.";
-  return 0;
+  qCWarning(KHC_LOG) << "ERROR! mCurrentItem is not set.";
+  return nullptr;
 }
 
 // vim:ts=2:sw=2:et
