@@ -22,11 +22,11 @@
 
 #include "searchwidget.h"
 
-#include <QLabel>
 #include <QComboBox>
-#include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QHash>
+#include <QLabel>
+#include <QVBoxLayout>
 
 #include <KConfig>
 #include <KLocalizedString>
@@ -84,8 +84,7 @@ SearchWidget::SearchWidget( SearchEngine *engine, QWidget *parent )
   for (int i=0; i < ScopeNum; ++i ) {
     mScopeCombo->addItem( scopeSelectionLabel( i ) );
   }
-  connect( mScopeCombo, SIGNAL( activated( int ) ),
-           SLOT( scopeSelectionChanged( int ) ) );
+  connect(mScopeCombo, QOverload<int>::of(&QComboBox::activated), this, &SearchWidget::scopeSelectionChanged);
 
   l = new QLabel( i18n("&Scope selection:"), this );
   l->setBuddy( mScopeCombo );
@@ -100,11 +99,9 @@ SearchWidget::SearchWidget( SearchEngine *engine, QWidget *parent )
 
 // FIXME: Use SearchHandler on double-clicked document
 #if 0
-  connect( mScopeListView, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int) ),
-           SLOT(scopeDoubleClicked(QTreeWidgetItem*)) );
+  connect(mScopeListView, &QTreeWidget::itemDoubleClicked, this, &SearchWidget::scopeDoubleClicked);
 #endif
-  connect( mScopeListView, SIGNAL(itemClicked(QTreeWidgetItem*,int)),
-           SLOT(scopeClicked(QTreeWidgetItem*)) );
+  connect(mScopeListView, &QTreeWidget::itemClicked, this, &SearchWidget::scopeClicked);
 }
 
 
@@ -208,9 +205,9 @@ void SearchWidget::scopeSelectionChanged( int id )
 
 QString SearchWidget::method() const
 {
-  QString m = "and";
+  QString m = QStringLiteral("and");
   if ( mMethodCombo->currentIndex() == 1)
-    m = "or";
+    m = QStringLiteral("or");
 
   return m;
 }
@@ -251,7 +248,7 @@ class ScopeTraverser : public DocEntryTraverser
       if( mParentItem->type() == TemporaryItem && !mParentItem->childCount() ) delete mParentItem;
     }
 
-    void process( DocEntry *entry ) Q_DECL_OVERRIDE
+    void process( DocEntry *entry ) override
     {
       if ( mEngine->canSearch( entry ) ) {
         ScopeItem *item = new ScopeItem( mParentItem, entry );
@@ -260,7 +257,7 @@ class ScopeTraverser : public DocEntryTraverser
       }
     }
 
-    DocEntryTraverser *createChild( DocEntry *entry ) Q_DECL_OVERRIDE
+    DocEntryTraverser *createChild( DocEntry *entry ) override
     {
       if ( mLevel >= MaxNestingLevel ) {
         ++mLevel;
@@ -276,13 +273,13 @@ class ScopeTraverser : public DocEntryTraverser
       }
     }
 
-    DocEntryTraverser *parentTraverser() Q_DECL_OVERRIDE
+    DocEntryTraverser *parentTraverser() override
     {
       if ( mLevel > MaxNestingLevel ) return this;
       else return mParent;
     }
 
-    void deleteTraverser() Q_DECL_OVERRIDE
+    void deleteTraverser() override
     {
       if ( mLevel > MaxNestingLevel ) --mLevel;
       else delete this;
@@ -322,7 +319,7 @@ void SearchWidget::scopeDoubleClicked( QTreeWidgetItem* item )
 
   QString searchUrl = scopeItem->entry()->search();
 
-  khcDebug() << "DoubleClick: " << searchUrl;
+  qCDebug(KHC_LOG) << "DoubleClick: " << searchUrl;
 
   emit searchResult( searchUrl );
 }
