@@ -23,22 +23,19 @@
 #include "docentry.h"
 #include "khc_debug.h"
 
+#include <QApplication>
+#include <QFileInfo>
+#include <QIcon>
+#include <QStandardPaths>
+#include <QStatusBar>
+#include <QTextStream>
+
 #include <KProcess>
 #include <KXmlGuiWindow>
 #include <kcoreaddons_version.h>
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 36, 0)
 #include <docbookxslt.h>
-#endif
-
-#include <QStatusBar>
-
-#include <QFileInfo>
-#include <QTextStream>
 
 #include <sys/stat.h>
-#include <QStandardPaths>
-#include <QApplication>
-#include <QIcon>
 
 using namespace KHC;
 
@@ -88,11 +85,7 @@ void TOC::build( const QString &file )
 {
     QFileInfo fileInfo( file );
     QString fileName = fileInfo.absoluteFilePath();
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 36, 0)
     const QStringList resourceDirs = KDocTools::documentationDirs();
-#else
-    const QStringList resourceDirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "doc/HTML", QStandardPaths::LocateDirectory);
-#endif
     QStringList::ConstIterator it = resourceDirs.begin();
     QStringList::ConstIterator end = resourceDirs.end();
     for ( ; it != end; ++it ) {
@@ -102,11 +95,11 @@ void TOC::build( const QString &file )
         }
     }
 
-    QString cacheFile = fileName.replace( '/', "__" );
+    QString cacheFile = fileName.replace( QLatin1Char('/'), QStringLiteral("__") );
 #ifdef Q_WS_WIN
-    cacheFile = cacheFile.replace( ':', "_" );
+    cacheFile = cacheFile.replace( QLatin1Char(':'), QStringLiteral("_") );
 #endif
-    m_cacheFile = QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + "/help/" + cacheFile ;
+    m_cacheFile = QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QStringLiteral("/help/") + cacheFile ;
     m_sourceFile = file;
 
     if ( cacheStatus() == NeedRebuild )
@@ -152,18 +145,17 @@ void TOC::buildCache()
     KXmlGuiWindow *mainWindow = dynamic_cast<KXmlGuiWindow *>( qobject_cast<QApplication*>(qApp)->activeWindow() );
 
     KProcess *meinproc = new KProcess;
-    connect( meinproc, SIGNAL( finished( int, QProcess::ExitStatus) ),
-             this, SLOT( meinprocExited( int, QProcess::ExitStatus) ) );
+    connect(meinproc, QOverload<int, QProcess::ExitStatus>::of(&KProcess::finished), this, &TOC::meinprocExited);
 
-    *meinproc << QStandardPaths::findExecutable("meinproc5");
-    *meinproc << "--stylesheet" << QStandardPaths::locate(QStandardPaths::GenericDataLocation, "khelpcenter/table-of-contents.xslt" );
-    *meinproc << "--output" << m_cacheFile;
+    *meinproc << QStandardPaths::findExecutable(QStringLiteral("meinproc5"));
+    *meinproc << QStringLiteral("--stylesheet") << QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("khelpcenter/table-of-contents.xslt") );
+    *meinproc << QStringLiteral("--output") << m_cacheFile;
     *meinproc << m_sourceFile;
 
     meinproc->setOutputChannelMode(KProcess::OnlyStderrChannel);
     meinproc->start();
     if (!meinproc->waitForStarted()) {
-        khcWarning() << "could not start process" << meinproc->program();
+        qCWarning(KHC_LOG) << "could not start process" << meinproc->program();
         if (mainWindow && !m_alreadyWarned) {
             ; // add warning message box with don't display again option 
               // http://api.kde.org/4.0-api/kdelibs-apidocs/kdeui/html/classKDialog.html
@@ -179,8 +171,8 @@ void TOC::meinprocExited( int exitCode, QProcess::ExitStatus exitStatus)
     KXmlGuiWindow *mainWindow = dynamic_cast<KXmlGuiWindow *>( qobject_cast<QApplication*>(qApp)->activeWindow() );
 
     if ( exitStatus == QProcess::CrashExit || exitCode != 0 ) {
-        khcWarning() << "running" << meinproc->program() << "failed with exitCode" << exitCode;
-        khcWarning() << "stderr output:" << meinproc->readAllStandardError();
+        qCWarning(KHC_LOG) << "running" << meinproc->program() << "failed with exitCode" << exitCode;
+        qCWarning(KHC_LOG) << "stderr output:" << meinproc->readAllStandardError();
         if (mainWindow && !m_alreadyWarned) {
             ; // add warning message box with don't display again option 
               // http://api.kde.org/4.0-api/kdelibs-apidocs/kdeui/html/classKDialog.html
@@ -233,8 +225,8 @@ void TOC::fillTree()
     if ( !doc.setContent( &f ) )
         return;
 
-    TOCChapterItem *chapItem = 0;
-    QDomNodeList chapters = doc.documentElement().elementsByTagName( "chapter" );
+    TOCChapterItem *chapItem = nullptr;
+    QDomNodeList chapters = doc.documentElement().elementsByTagName( QStringLiteral("chapter") );
     for ( int chapterCount = 0; chapterCount < chapters.count(); chapterCount++ ) {
         QDomElement chapElem = chapters.item( chapterCount ).toElement();
         QDomElement chapTitleElem = childElement( chapElem, QLatin1String( "title" ) );
@@ -244,8 +236,8 @@ void TOC::fillTree()
 
         chapItem = new TOCChapterItem( this, m_parentItem, chapItem, chapTitle, chapRef );
 
-        TOCSectionItem *sectItem = 0;
-        QDomNodeList sections = chapElem.elementsByTagName( "section" );
+        TOCSectionItem *sectItem = nullptr;
+        QDomNodeList sections = chapElem.elementsByTagName( QStringLiteral("section") );
         for ( int sectCount = 0; sectCount < sections.count(); sectCount++ ) {
             QDomElement sectElem = sections.item( sectCount ).toElement();
             QDomElement sectTitleElem = childElement( sectElem, QLatin1String( "title" ) );
@@ -303,16 +295,16 @@ TOCSectionItem::TOCSectionItem( TOC *toc, TOCChapterItem *parent, QTreeWidgetIte
     : TOCItem( toc, parent, after, title ),
     m_name( name )
 {
-    setIcon( 0, QIcon::fromTheme( "text-plain" ) );
+    setIcon( 0, QIcon::fromTheme( QStringLiteral("text-plain") ) );
     entry()->setUrl(url());
 }
 
 QString TOCSectionItem::url()
 {
     if ( static_cast<TOCSectionItem *>( parent()->child(0) ) == this )
-        return static_cast<TOCChapterItem *>( parent() )->url() + '#' + m_name;
+        return static_cast<TOCChapterItem *>( parent() )->url() + QLatin1Char('#') + m_name;
 
-    return "help:" + toc()->application() + '/' + m_name + ".html";
+    return QStringLiteral("help:") + toc()->application() + QLatin1Char('/') + m_name + QStringLiteral(".html");
 }
 
 
